"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OvenStatus = void 0;
const baseDevice_1 = require("../baseDevice");
var OvenState, OvenMode;
(function (OvenState) {
    OvenState["INITIAL"] = "@OV_STATE_INITIAL_W";
    OvenState["PREHEATING"] = "@OV_STATE_PREHEAT_W";
    OvenState["COOKING_IN_PROGRESS"] = "@OV_STATE_COOK_W";
    OvenState["DONE"] = "@OV_STATE_COOK_COMPLETE_W";
    OvenState["COOLING"] = "@OV_TERM_COOLING_W";
    OvenState["CLEANING"] = "@OV_STATE_CLEAN_W";
    OvenState["CLEANING_DONE"] = "@OV_STATE_CLEAN_COMPLETE_W";
})(OvenState = exports.OvenState || (exports.OvenState = {}));

(function (OvenMode) {
    OvenMode["NONE"] = "@NONE";
    OvenMode["BAKE"] = "@OV_TERM_BAKE_W";
    OvenMode["ROAST"] = "@OV_TERM_ROAST_W";
    OvenMode["CONVECTION_BAKE"] = "@OV_TERM_CONV_BAKE_W";
    OvenMode["CONVECTION_ROAST"] = "@OV_TERM_CONV_ROAST_W";
    OvenMode["CRISP_CONVECTION"] = "@OV_TERM_CRISP_CONV_W";
    OvenMode["FAVORITE"] = "@OV_TERM_COOKMODE_FAVORITE_W";
    OvenMode["BROIL"] = "@OV_TERM_BROIL_W";
    OvenMode["WARM"] = "@OV_TERM_WARM_W";
    OvenMode["PROOF"] = "@OV_TERM_PROOF_W";
    OvenMode["FROZEN_MEAL"] = "@OV_TERM_FROZEN_MEAL_W";
    OvenMode["SLOW_COOK"] = "@OV_TERM_SLOW_COOK_W";
    OvenMode["PROBE_SET"] = "@OV_TERM_PROBE_SET_W";
    OvenMode["EASY_CLEAN"] = "@OV_TERM_EASY_CLEAN_W";
    OvenMode["SPEED_BROIL"] = "@OV_TERM_SPEED_BROIL_W";
    OvenMode["SELF_CLEAN"] = "@OV_TERM_SELF_CLEAN_W";
    OvenMode["SPEED_ROAST"] = "@OV_TERM_SPEED_ROAST_W";
    OvenMode["AIR_FRY"] = "@OV_TERM_AIR_FRY_W";
    OvenMode["PIZZA"] = "@OV_TERM_PIZZA_W";
    OvenMode["AIR_SOUSVIDE"] = "@OV_TERM_AIR_SOUSVIDE_W";
})(OvenMode = exports.OvenMode || (exports.OvenMode = {}));

class Oven extends baseDevice_1.baseDevice {
    constructor(platform, accessory) {
        super(platform, accessory);
        this.platform = platform;
        this.accessory = accessory;
        this.inputNameStatus = "Oven Status";
        this.inputNameMode = "Oven Mode";
        this.probeName = 'Oven Probe Status';
        this.courseStartString = 'Oven Start Time Not Set';
        this.courseTimeString = 'Oven Baking Time Not Set';
        this.courseTimeEndString = 'Oven End Time Not Set';
        this.inputNameOptions = "Oven Options";
        this.inputNameBurner1 = 'Front Left Burner Status';
        this.inputNameBurner2 = 'Back Left Burner Status';
        this.inputNameBurner3 = 'Center Burner Status';
        this.inputNameBurner4 = 'Front Right Burner Status';
        this.inputNameBurner5 = 'Back Right Burner Status';
        this.inputID = 1;
        const { Service: { Valve, ContactSensor, OccupancySensor, IrrigationSystem }, Characteristic, } = this.platform;
        const device = accessory.context.device;




        this.ovenService = this.accessory.getService(this.config.name) ||
            this.accessory.addService(this.platform.Service.Television, this.config.name, 'NicoCataGaTa-OvenOven7');
        this.ovenService.setCharacteristic(this.platform.Characteristic.ConfiguredName, "LG Range");
        this.ovenService.setCharacteristic(this.platform
            .Characteristic.SleepDiscoveryMode, this.platform.Characteristic.SleepDiscoveryMode.ALWAYS_DISCOVERABLE);
        this.ovenService.getCharacteristic(this.platform.Characteristic.Active)
            .onSet(this.setActive.bind(this))
            .updateValue(this.platform.Characteristic.Active.ACTIVE);
        this.ovenService
            .setCharacteristic(this.platform.Characteristic.ActiveIdentifier, this.inputID);
        this.ovenService
            .getCharacteristic(this.platform.Characteristic.ActiveIdentifier)
            .on('set', (inputIdentifier, callback) => {
                if (inputIdentifier === 1) {
                    this.inputID = 1;
                }
                else if (inputIdentifier === 2) {
                    this.inputID = 2;
                }
                else if (inputIdentifier === 3) {
                    this.inputID = 3;
                }
                else if (inputIdentifier === 4) {
                    this.inputID = 4;
                }
                else if (inputIdentifier === 5) {
                    this.inputID = 5;
                }
                else if (inputIdentifier === 6) {
                    this.inputID = 6;
                }
                else if (inputIdentifier === 7) {
                    this.inputID = 7;
                }
                else if (inputIdentifier === 8) {
                    this.inputID = 7;
                }
                else if (inputIdentifier === 9) {
                    this.inputID = 7;
                }
                else if (inputIdentifier === 10) {
                    this.inputID = 7;
                }
                else if (inputIdentifier === 11) {
                    this.inputID = 7;
                }
                else if (inputIdentifier === 12) {
                    this.inputID = 7;
                }
                else {
                    this.inputID = 1;
                }
                callback();
            })
            .on('get', (callback) => {
                let currentValue = this.inputID;
                callback(null, currentValue);
            });
        this.ovenState = this.accessory.getService('Oven Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Oven Status', 'NicoCataGaTa-Oven1003')
                .setCharacteristic(this.platform.Characteristic.Identifier, 1)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameStatus)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.platform.Characteristic.CurrentVisibilityState.SHOWN);
        this.ovenState.getCharacteristic(this.platform.Characteristic.ConfiguredName)
            .on('get', (callback) => {
                let currentValue = this.ovenStatus();
                callback(null, currentValue);
            });
        this.ovenService.addLinkedService(this.ovenState);
        this.ovenMode = this.accessory.getService('Oven Mode') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Oven Mode', 'NicoCataGaTa-Oven1004')
                .setCharacteristic(this.platform.Characteristic.Identifier, 2)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameMode)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.onStatus() ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.onStatus() ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenMode.getCharacteristic(this.platform.Characteristic.ConfiguredName)
            .on('get', (callback) => {
                let currentValue = this.ovenModeName();
                callback(null, currentValue);
            });
        this.ovenService.addLinkedService(this.ovenMode);

        this.prove = this.accessory.getService('Probe Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Probe Status', 'NicoCata-Always15')
                .setCharacteristic(this.platform.Characteristic.Identifier, 3)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.probeName)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showProbe ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showProbe ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.prove);

        this.ovenStart = this.accessory.getService('Oven Start Time') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Oven Start Time', 'NicoCata-Always1')
                .setCharacteristic(this.platform.Characteristic.Identifier, 4)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.courseStartString)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showTime ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showTime ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.ovenStart);

        this.ovenTimer = this.accessory.getService('Oven Timer') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Oven Timer', 'NicoCata-Always2')
                .setCharacteristic(this.platform.Characteristic.Identifier, 5)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.courseTimeString)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showTime ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showTime ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.ovenTimer);




        this.ovenEndTime = this.accessory.getService('Oven Ending Time') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Oven Ending Time', 'NicoCata-Always3')
                .setCharacteristic(this.platform.Characteristic.Identifier, 6)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.courseTimeEndString)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showTime ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showTime ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.ovenEndTime);

        this.ovenOptions = this.accessory.getService('Oven Options') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Oven Options', 'NicoCata-Always4')
                .setCharacteristic(this.platform.Characteristic.Identifier, 7)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameOptions)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showOptions ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showOptions ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.ovenOptions);



        this.burner1 = this.accessory.getService('Front Left Burner Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Front Left Burner Status', 'NicoCataGaTa-Oven001')
                .setCharacteristic(this.platform.Characteristic.Identifier, 8)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner1)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showBurner1 ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showBurner1 ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.burner1);

        this.burner2 = this.accessory.getService('Back Left Burner Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Back Left Burner Status', 'NicoCataGaTa-Oven002')
                .setCharacteristic(this.platform.Characteristic.Identifier, 9)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner2)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showBurner2 ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showBurner2 ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.burner2);

        this.burner3 = this.accessory.getService('Center Burner Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Center Burner Status', 'NicoCataGaTa-Oven003')
                .setCharacteristic(this.platform.Characteristic.Identifier, 10)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner3)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showBurner3 ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showBurner3 ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.burner3);

        this.burner4 = this.accessory.getService('Front Right Burner Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Front Right Burner Status', 'NicoCataGaTa-Oven004')
                .setCharacteristic(this.platform.Characteristic.Identifier, 11)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner4)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showBurner4 ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showBurner4 ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.burner4);
        this.burner5 = this.accessory.getService('Back Right Burner Status') ||
            this.accessory.addService(this.platform.Service.InputSource, 'Back Right Burner Status', 'NicoCataGaTa-Oven005')
                .setCharacteristic(this.platform.Characteristic.Identifier, 12)
                .setCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner5)
                .setCharacteristic(this.platform.Characteristic.IsConfigured, this.platform.Characteristic.IsConfigured.CONFIGURED)
                .setCharacteristic(this.platform.Characteristic.InputSourceType, this.platform.Characteristic.InputSourceType.APPLICATION)
                .setCharacteristic(this.platform.Characteristic.TargetVisibilityState, this.showBurner5 ? this.platform.Characteristic.TargetVisibilityState.SHOWN : this.platform.Characteristic.TargetVisibilityState.HIDDEN)
                .setCharacteristic(this.platform.Characteristic.CurrentVisibilityState, this.showBurner5 ? this.platform.Characteristic.CurrentVisibilityState.SHOWN : this.platform.Characteristic.CurrentVisibilityState.HIDDEN);
        this.ovenService.addLinkedService(this.burner5);
        /*
        
                this.timers = accessory.getService(IrrigationSystem) || accessory.addService(IrrigationSystem, 'Oven Timers', 'NicoCataGaTa-OvenT0');
                this.timers.setCharacteristic(Characteristic.Name, 'Oven Timers');
                this.timers.getCharacteristic(Characteristic.Active)
                    .onSet(this.setActive.bind(this))
                    .updateValue(Characteristic.Active.INACTIVE);
                this.timers.setCharacteristic(Characteristic.InUse, Characteristic.InUse.NOT_IN_USE);
                this.timers.getCharacteristic(Characteristic.RemainingDuration).setProps({
                    maxValue: 3600, // 1 day
                });
                this.timers.getCharacteristic(this.platform.Characteristic.SetDuration).setProps({
                    maxValue: 3600, // 1 day
                });
        
        
        */




        //////////Timers
        this.ovenTimerService = accessory.getService(Valve) || accessory.addService(Valve, 'Oven Timer Service', 'NicoCataGaTa-OvenT2');
        this.ovenTimerService.setCharacteristic(Characteristic.Name, 'Oven Timer Service');
        this.ovenTimerService.setCharacteristic(Characteristic.ValveType, Characteristic.ValveType.SHOWER_HEAD);
        this.ovenTimerService.getCharacteristic(Characteristic.Active)
            .onSet(this.setActive.bind(this))
            .updateValue(Characteristic.Active.INACTIVE);
        this.ovenTimerService.getCharacteristic(Characteristic.ServiceLabelIndex, 1);
        this.ovenTimerService.setCharacteristic(Characteristic.InUse, Characteristic.InUse.NOT_IN_USE);
        this.ovenTimerService.getCharacteristic(Characteristic.RemainingDuration).setProps({
            maxValue: 86400, // 1 day
        });
        this.ovenTimerService.getCharacteristic(this.platform.Characteristic.SetDuration).setProps({
            maxValue: 86400, // 1 day
        });
        //this.timers.addLinkedService(this.ovenTimerService);


        this.ovenAlarmService = accessory.getService(Valve) || accessory.addService(Valve, 'Oven Alarm Service', 'NicoCataGaTa-OvenT2');
        this.ovenAlarmService.setCharacteristic(Characteristic.Name, 'Oven Alarm Service');
        this.ovenTimerService.setCharacteristic(Characteristic.ValveType, Characteristic.ValveType.WATER_FAUCET);
        this.ovenAlarmService.getCharacteristic(Characteristic.Active)
            .onSet(this.setActive.bind(this))
            .updateValue(Characteristic.Active.INACTIVE);
        this.ovenAlarmService.getCharacteristic(Characteristic.ServiceLabelIndex, 2);
        this.ovenAlarmService.setCharacteristic(Characteristic.InUse, Characteristic.InUse.NOT_IN_USE);
        this.ovenAlarmService.getCharacteristic(Characteristic.RemainingDuration).setProps({
            maxValue: 3600, // 1 day
        });
        this.ovenAlarmService.getCharacteristic(this.platform.Characteristic.SetDuration).setProps({
            maxValue: 3600, // 1 day
        });
        // this.timers.addLinkedService(this.ovenAlarmService);

        ////////////Buttons
        this.bakeSwitch = accessory.getService('Bake Mode') ||
            accessory.addService(this.platform.Service.Switch, 'Bake Mode', 'CataNicoGaTa-80');
        this.bakeSwitch.getCharacteristic(this.platform.Characteristic.On)
            .on('get', (callback) => {
                this.platform.log.debug('Bake Switch Get state');
                let currentValue = false;
                callback(null, currentValue);
            })
            .on('set', (value, callback) => {
                this.platform.log('Bake:', value);
                if (value === true) {
                    var _a;
                    const device = this.accessory.context.device;
                    (_a = this.platform.ThinQ) === null || _a === void 0 ? void 0 : _a.deviceControl(device, {
                        dataKey: null,
                        dataValue: null,
                        dataSetList: {
                            ovenState: {
                                upperRemoteStartUsing: "BAKE",
                            },
                        },
                        dataGetList: null,
                    });
                }
                callback(null);
            });






    }

    setActive() {
        this.platform.log('Oven Response 1', this.Status.deviceModel.data)
        //  this.platform.log('Oven Response 2', this.Status.deviceModel.DeviceModel.data.ControlWifi);
        // this.platform.log('Oven Response 3', this.Status.deviceModel.DeviceModel.data.UpperManualCook);
        //this.platform.log('Oven Response 4', this.Status.deviceModel.DeviceModel.data.Monitoring);
        // this.platform.log('Dishwasher rinse', this.Status.data.rinseLevel);
        //  this.platform.log('Dishwasher rinse typeof', typeof this.Status.data.rinseLevel);
        //this.updateRinseLevel();
        //  this.platform.log('Dishwasher rinse status', this.rinseStatus);
        // this.serviceDishwasher.updateCharacteristic(this.platform.Characteristic.StatusFault, this.rinseStatus);
        // this.platform.log('Dishwasher Response', this.Status);
        // throw new this.platform.api.hap.HapStatusError(-70412 /* this.platform.api.hap.HAPStatus.NOT_ALLOWED_IN_CURRENT_STATE */);
    }
    onStatus() {
        return false;
    }

    remainTime() {
        let remainingDuration = 0;
        if (typeof this.Status.data?.upperRemainTimeHour != "undefined") {
            remainingDuration += this.Status.data?.upperRemainTimeHour * 3600;
        }
        if (typeof this.Status.data?.upperRemainTimeSecond != "undefined") {
            remainingDuration += this.Status.data?.upperRemainTimeMinute * 60;
        }

        if (typeof this.Status.data?.upperRemainTimeSecond != "undefined") {
            remainingDuration += this.Status.data?.upperRemainTimeSecond * 60;
        }
        return remainingDuration
    }
    ovenModeName() {
        this.inputNameMode = "Oven Mode: "
        switch (this.Status.data?.upperManualCookName) {
            case "NONE":
                this.inputNameMode += "None";
                break;
            case "BAKE":
                this.inputNameMode += "Bake";
                break;
            case "ROAST":
                this.inputNameMode += "Roast";
                break;
            case "CONVECTION_BAKE":
                this.inputNameMode += "Convection Bake";
                break;
            case "CONVECTION_ROAST":
                this.inputNameMode += "Convection Roast";
                break;
            case "CRISP_CONVECTION":
                this.inputNameMode += "Crisp Convection";
                break;
            case "FAVORITE":
                this.inputNameMode += "Favorite";
                break;
            case "BROIL":
                this.inputNameMode += "Broil";
                break;
            case "WARM":
                this.inputNameMode += "Warm";
                break;
            case "PROOF":
                this.inputNameMode += "Proof";
                break;
            case "FROZEN_MEAL":
                this.inputNameMode += "Frozen Meal";
                break;
            case "SLOW_COOK":
                this.inputNameMode += "Slow Cook";
                break;
            case "PROBE_SET":
                this.inputNameMode += "Probe Set";
                break;
            case "EASY_CLEAN":
                this.inputNameMode += "Easy Clean";
                break;
            case "SPEED_BROIL":
                this.inputNameMode += "Speed Broil";
                break;
            case "SELF_CLEAN":
                this.inputNameMode += "Self Clean";
                break;
            case "SPEED_ROAST":
                this.inputNameMode += "Speed Roast";
                break;
            case "AIR_FRY":
                this.inputNameMode += "Air Fry";
                break;
            case "PIZZA":
                this.inputNameMode += "Pizza";
                break;
            case "AIR_SOUSVIDE":
                this.inputNameMode += "Air Sousvide";
                break;
            default:
                let cookName = this.Status.data?.upperManualCookName;
                cookName = cookName.toLocaleLowerCase();
                let cookNameCap =
                    cookName.charAt(0).toUpperCase()
                    + cookName.slice(1);
                this.inputNameMode += cookNameCap;

        }
        return this.inputNameMode
    }

    ovenStatus() {
        this.inputNameStatus = "Oven Status: "
        switch (this.Status.data?.upperState) {
            case "INITIAL":
                this.inputNameStatus += "Standby";
                break;
            case "PREHEATING":
                this.inputNameStatus += "Preheating";
                break;
            case "COOKING_IN_PROGRESS":
                this.inputNameStatus += "Cooking in Progress";
                break;
            case "DONE":
                this.inputNameStatus += "Done";
                break;
            case "COOLING":
                this.inputNameStatus += "Cooling";
                break;
            case "CLEANING":
                this.inputNameStatus += "Cleaning";
                break;
            case "CLEANING_DONE":
                this.inputNameStatus += "Cleaning Done";
                break;
            default:
                let stateName = this.Status.data?.upperState;
                stateName = stateName.toLocaleLowerCase();
                let stateNameCap =
                    stateName.charAt(0).toUpperCase()
                    + stateName.slice(1);
                this.inputNameStatus += stateNameCap;

        }
        return this.inputNameStatus
    }

    ovenTemperature() {
        /////Current Temp
        if (this.Status.data?.upperCurrentTemperatureValue != 0) {
            this.inputNameStatus += ". Current Temp: " + this.Status.data?.upperCurrentTemperatureValue + "°";
        }

        ////Set temperature
        if (this.Status.data?.upperTargetTemperatureValue != 0) {
            this.inputNameStatus += ". Set Temp: " + this.Status.data?.upperTargetTemperatureValue + "°";
        }
    }
    OvenSubCookMenu() {
        if (this.Status.data?.upperSubCookMenu != "NONE" && typeof this.Status.data?.upperSubCookMenu != "undefined") {
            let subCook = this.Status.data?.upperSubCookMenu;
            subCook = subCook.toLocaleLowerCase();
            let subCookCap =
                subCook.charAt(0).toUpperCase()
                + subCook.slice(1);
            this.subCookName = subCookCap;
            this.inputNameMode += " (" + this.subCookName + ")"
        }
    }
    oventTargetTime() {
        let setDuration = 0;
        if (typeof this.Status.data?.upperTargetTimeHour != "undefined") {
            setDuration += this.Status.data?.upperTargetTimeHour * 3600;
        }
        if (typeof this.Status.data?.upperTargetTimeMinute != "undefined") {
            setDuration += this.Status.data?.upperTargetTimeMinute * 60;
        }

        if (typeof this.Status.data?.upperTargetTimeSecond != "undefined") {
            setDuration += this.Status.data?.upperTargetTimeSecond * 60;
        }
    }
    oventTimerTime() {
        let setTimerDuration = 0;
        if (typeof this.Status.data?.upperTimerHour != "undefined") {
            setTimerDuration += this.Status.data?.upperTimerHour * 3600;
        }
        if (typeof this.Status.data?.upperTimerMinute != "undefined") {
            setTimerDuration += this.Status.data?.upperTimerMinute * 60;
        }

        if (typeof this.Status.data?.upperTimerSecond != "undefined") {
            setTimerDuration += this.Status.data?.upperTimerSecond * 60;
        }
    }
    proveStatus() {
        if (this.Status.data?.upperCurrentProveTemperatureF !== 0 && typeof this.Status.data?.upperCurrentProveTemperatureF != "undefined") {
            this.proveName = "Current probe Temperature: " + this.Status.data?.upperCurrentProveTemperatureF + "°";
            this.showProbe = true
            if (this.Status.data?.upperTargetProveTemperatureF !== 0 && typeof this.Status.data?.upperTargetProveTemperatureF != "undefined") {
                this.ProveName += ". Set Temp: " + this.Status.data?.upperTargetProveTemperatureF + "°";
                this.showProbe = true;
            }
        }
        else {
            this.proveName = 'Probe Status';
            this.showProbe = false;
        }
    }
    createCook(key) {
        const { Service: { HeaterCooler, }, Characteristic, } = this.platform;
        const device = this.accessory.context.device;
        const service = this.accessory.getService(HeaterCooler) || this.accessory.addService(HeaterCooler, device.name);
        service.getCharacteristic(Characteristic.CurrentHeaterCoolerState)
            .onGet(() => {
                const currentState = device.deviceModel.lookupMonitorValue('UpperOvenState', this.Status.getState(key));
                if (currentState === OvenState.COOLING) {
                    return Characteristic.CurrentHeaterCoolerState.COOLING;
                }
                else if ([OvenState.PREHEATING, OvenState.COOKING_IN_PROGRESS].includes(currentState)) {
                    return Characteristic.CurrentHeaterCoolerState.HEATING;
                }
                else {
                    return Characteristic.CurrentHeaterCoolerState.IDLE;
                }
            });
        service.getCharacteristic(Characteristic.TargetHeaterCoolerState)
            .setProps({
                validValues: [Characteristic.TargetHeaterCoolerState.HEAT],
                perms: ["ev" /* NOTIFY */, "pr" /* PAIRED_READ */],
            });
    }
    burnerState() {
        if (this.Status.data?.cooktop1CooktopState !== "INIT" && typeof this.Status.data?.cooktop1CooktopState != "undefined") {

            let burnerOperationTime = 0;
            if (typeof this.Status.data?.cooktop1OperationTimeHour != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop1OperationTimeHour * 3600;
            }
            if (typeof this.Status.data?.cooktop1OperationTimeMinute != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop1OperationTimeMinute * 60;
            }

            if (typeof this.Status.data?.cooktop1OperationTimeSecond != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop1OperationTimeSecond * 60;
            }
            if (burnerOperationTime !== 0) {
                this.inputNameBurner1 = "Front Left Burner is On. Cooking for " + this.getOperationTime(burnerOperationTime);
            }
            else {
                this.inputNameBurner1 = "Front Left Burner  is On";
                this.showBurner1 = true;
            }
        }
        else {
            this.inputNameBurner1 = "Front Left Burner Not in Use"
            this.showBurner1 = false;
        }



        if (this.Status.data?.cooktop2CooktopState !== "INIT" && typeof this.Status.data?.cooktop2CooktopState != "undefined") {

            let burnerOperationTime = 0;
            if (typeof this.Status.data?.cooktop2OperationTimeHour != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop2OperationTimeHour * 3600;
            }
            if (typeof this.Status.data?.cooktop1OperationTimeMinute != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop2OperationTimeMinute * 60;
            }

            if (typeof this.Status.data?.cooktop1OperationTimeSecond != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop2OperationTimeSecond * 60;
            }
            if (burnerOperationTime !== 0) {
                this.inputNameBurner2 = "Back Left Burner is On. Cooking for " + this.getOperationTime(burnerOperationTime);
            }
            else {
                this.inputNameBurner2 = "Back Left Burner is On";
                this.showBurner2 = true;
            }
        }
        else {
            this.inputNameBurner2 = "Back Left Burner Not in Use"
            this.showBurner2 = false;
        }




        if (this.Status.data?.cooktop3CooktopState !== "INIT" && typeof this.Status.data?.cooktop3CooktopState != "undefined") {

            let burnerOperationTime = 0;
            if (typeof this.Status.data?.cooktop3OperationTimeHour != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop3OperationTimeHour * 3600;
            }
            if (typeof this.Status.data?.cooktop3OperationTimeMinute != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop3OperationTimeMinute * 60;
            }

            if (typeof this.Status.data?.cooktop3OperationTimeSecond != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop3OperationTimeSecond * 60;
            }
            if (burnerOperationTime !== 0) {
                this.inputNameBurner3 = "Center Burner is On. Cooking for " + this.getOperationTime(burnerOperationTime);
            }
            else {
                this.inputNameBurner3 = "Center Burner is On";
            }
            this.showBurner3 = true;
        }
        else {
            this.inputNameBurner3 = "Center Burner Not in Use"
            this.showBurner3 = false;
        }

        if (this.Status.data?.cooktop4CooktopState !== "INIT" && typeof this.Status.data?.cooktop4CooktopState != "undefined") {

            let burnerOperationTime = 0;
            if (typeof this.Status.data?.cooktop4OperationTimeHour != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop4OperationTimeHour * 3600;
            }
            if (typeof this.Status.data?.cooktop4OperationTimeMinute != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop4OperationTimeMinute * 60;
            }

            if (typeof this.Status.data?.cooktop4OperationTimeSecond != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop4OperationTimeSecond * 60;
            }
            if (burnerOperationTime !== 0) {
                this.inputNameBurner4 = "Front Right Burner is On. Cooking for " + this.getOperationTime(burnerOperationTime);
            }
            else {
                this.inputNameBurner4 = "Front Right Burner is On";
            }
            this.showBurner4 = true;
        }
        else {
            this.inputNameBurner4 = "Front Right Burner Not in Use"
            this.showBurner4 = false;
        }

        if (this.Status.data?.cooktop5CooktopState !== "INIT" && typeof this.Status.data?.cooktop5CooktopState != "undefined") {

            let burnerOperationTime = 0;
            if (typeof this.Status.data?.cooktop5OperationTimeHour != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop5OperationTimeHour * 3600;
            }
            if (typeof this.Status.data?.cooktop5OperationTimeMinute != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop5OperationTimeMinute * 60;
            }

            if (typeof this.Status.data?.cooktop5OperationTimeSecond != "undefined") {
                burnerOperationTime += this.Status.data?.cooktop5OperationTimeSecond * 60;
            }
            if (burnerOperationTime !== 0) {
                this.inputNameBurner5 = "Back Right Burner is On. Cooking for " + this.getOperationTime(burnerOperationTime);
            }
            else {
                this.inputNameBurner5 = "BBack Right Burner is On";
            }
            this.showBurner5 = true;
        }
        else {
            this.inputNameBurner5 = "Back Right Burner Not in Use"
            this.showBurner5 = false;
        }
    }
    getOperationTime(timeInSeconds) {

        let newTime = new Date(0);
        newTime.setSeconds(parseInt(timeInSeconds));
        let newTimeString = newTime.toISOString().substr(11, 8);

        if (newTimeString.startsWith('0')) {
            newTimeString = newTimeString.substring(1);
        }
        let hourMinutes = 'Minutes';
        if (timeInSeconds > 3600) {
            hourMinutes = 'Hours';
        }
        if (timeInSeconds == 3600) {
            hourMinutes = 'Hour';

        }
        return newTimeString + " " + hourMinutes
    }

    get Status() {
        var _a;
        return new OvenStatus((_a = this.accessory.context.device.snapshot) === null || _a === void 0 ? void 0 : _a.ovenState, this.accessory.context.device.deviceModel);
    }
    get config() {
        return Object.assign({}, {
            oven_trigger: false,
        }, super.config);
    }
    updateAccessoryCharacteristic(device) {
        super.updateAccessoryCharacteristic(device);
        const { Characteristic } = this.platform;
        this.platform.log('Update Accessorry received');
        this.burnerState();
        this.proveStatus();
        this.ovenTemperature();
        this.ovenModeName();
        this.OvenSubCookMenu();

        if (this.ovenState.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameStatus) {
            this.ovenState.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameStatus);
        }
        if (this.ovenMode.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameMode) {
            this.ovenMode.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameMode);
        }
        if (this.prove.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.probeName) {
            this.prove.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.probeName);
        }

        if (this.ovenStart.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.courseStartString) {
            this.ovenStart.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.courseStartString);
        }
        if (this.ovenTimer.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.courseTimeString) {
            this.ovenTimer.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.courseTimeString);
        }
        if (this.ovenEndTime.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.courseTimeEndString) {
            this.ovenEndTime.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.courseTimeEndString);
        }
        if (this.ovenOptions.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameOptions) {
            this.ovenOptions.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameOptions);
        }
        if (this.burner1.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameBurner1) {
            this.burner1.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner1);
        }
        if (this.burner2.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameBurner2) {
            this.burner2.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner2);
        }
        if (this.burner3.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameBurner3) {
            this.burner3.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner3);
        }
        if (this.burner4.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameBurner4) {
            this.burner4.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner4);
        }
        if (this.burner5.getCharacteristic(this.platform.Characteristic.ConfiguredName).value !== this.inputNameBurner5) {
            this.burner5.updateCharacteristic(this.platform.Characteristic.ConfiguredName, this.inputNameBurner5);
        }

    }

    update(snapshot) {
        super.update(snapshot);
        const oven = snapshot.oven;
        this.platform.log('Snapshot update Received');

        if (!oven) {
            return;
        }
    }
}
exports.default = Oven;
class OvenStatus {
    constructor(data, deviceModel) {
        this.data = data;
        this.deviceModel = deviceModel;
    }
    getState(key) {
        return this.data[key + 'State'];
    }
}
exports.OvenStatus = OvenStatus;
//# sourceMappingURL=constants.js.map